@@ -1,6 +1,7 @@
 //! Resizable queue implementation
 
 use std::convert::TryInto;
+use std::fmt::Debug;
 use std::iter::FromIterator;
 use std::sync::atomic::{AtomicUsize, Ordering};
 
@@ -18,7 +19,7 @@ use crate::unlimited::Queue as UnlimitedQueue;
 ///   - Supports resizing
 ///   - Enabled via the `resizable` feature in your `Cargo.toml`
 pub struct Queue<T> {
-    base: UnlimitedQueue<T>,
+    queue: UnlimitedQueue<T>,
     capacity: AtomicUsize,
     push_semaphore: Semaphore,
     resize_mutex: Mutex<()>,
@@ -28,7 +29,7 @@ impl<T> Queue<T> {
     /// Create new empty queue
     pub fn new(max_size: usize) -> Self {
         Self {
-            base: UnlimitedQueue::new(),
+            queue: UnlimitedQueue::new(),
             capacity: AtomicUsize::new(max_size),
             push_semaphore: Semaphore::new(max_size),
             resize_mutex: Mutex::default(),
@@ -37,14 +38,14 @@ impl<T> Queue<T> {
     /// Get an item from the queue. If the queue is currently empty
     /// this method blocks until an item is available.
     pub async fn pop(&self) -> T {
-        let item = self.base.pop().await;
+        let item = self.queue.pop().await;
         self.push_semaphore.add_permits(1);
         item
     }
     /// Try to get an item from the queue. If the queue is currently
     /// empty return None instead.
     pub fn try_pop(&self) -> Option<T> {
-        let item = self.base.try_pop();
+        let item = self.queue.try_pop();
         if item.is_some() {
             self.push_semaphore.add_permits(1);
         }
@@ -53,7 +54,7 @@ impl<T> Queue<T> {
     /// Push an item into the queue
     pub async fn push(&self, item: T) {
         let permit = self.push_semaphore.acquire().await.unwrap();
-        self.base.push(item);
+        self.queue.push(item);
         permit.forget();
     }
     /// Try to push an item to the queue. If the queue is currently
@@ -61,7 +62,7 @@ impl<T> Queue<T> {
     pub fn try_push(&self, item: T) -> Result<(), T> {
         match self.push_semaphore.try_acquire() {
             Ok(permit) => {
-                self.base.push(item);
+                self.queue.push(item);
                 permit.forget();
                 Ok(())
             }
@@ -74,13 +75,17 @@ impl<T> Queue<T> {
     }
     /// Get current length of queue
     pub fn len(&self) -> usize {
-        self.base.len()
+        self.queue.len()
+    }
+    /// Returns `true` if the queue is empty.
+    pub fn is_empty(&self) -> bool {
+        self.queue.is_empty()
     }
     /// The number of available items in the queue. If there are no
     /// items in the queue this number can become negative and stores the
     /// number of futures waiting for an item.
     pub fn available(&self) -> isize {
-        self.base.available()
+        self.queue.available()
     }
     /// Resize queue. This increases or decreases the queue
     /// capacity accordingly.
@@ -91,27 +96,42 @@ impl<T> Queue<T> {
     /// push items to the queue.
     pub async fn resize(&mut self, new_max_size: usize) {
         let _guard = self.resize_mutex.lock().await;
-        if new_max_size > self.capacity() {
-            let diff = new_max_size - self.capacity();
-            self.capacity.fetch_add(diff, Ordering::Relaxed);
-            self.push_semaphore.add_permits(diff);
-        } else if new_max_size < self.capacity() {
-            for _ in self.capacity()..new_max_size {
-                let permit = self.push_semaphore.acquire().await.unwrap();
-                self.capacity.fetch_sub(1, Ordering::Relaxed);
-                permit.forget();
-                self.base.pop().await;
+        match new_max_size.cmp(&self.capacity()) {
+            std::cmp::Ordering::Greater => {
+                let diff = new_max_size - self.capacity();
+                self.capacity.fetch_add(diff, Ordering::Relaxed);
+                self.push_semaphore.add_permits(diff);
             }
+            std::cmp::Ordering::Less => {
+                for _ in self.capacity()..new_max_size {
+                    let permit = self.push_semaphore.acquire().await.unwrap();
+                    self.capacity.fetch_sub(1, Ordering::Relaxed);
+                    permit.forget();
+                    self.queue.pop().await;
+                }
+            }
+            _ => {}
         }
     }
 }
 
+impl<T> Debug for Queue<T> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Queue")
+            .field("queue", &self.queue)
+            .field("capacity", &self.capacity)
+            .field("push_semaphore", &self.push_semaphore)
+            .field("resize_mutex", &self.resize_mutex)
+            .finish()
+    }
+}
+
 impl<T> FromIterator<T> for Queue<T> {
     fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
-        let base = UnlimitedQueue::from_iter(iter);
-        let len = base.len();
+        let queue = UnlimitedQueue::from_iter(iter);
+        let len = queue.len();
         Self {
-            base,
+            queue,
             capacity: len.try_into().unwrap(),
             push_semaphore: Semaphore::new(0),
             resize_mutex: Mutex::default(),
