@@ -1,6 +1,7 @@
 //! Unlimited queue implementation
 
 use std::convert::TryInto;
+use std::fmt::Debug;
 use std::iter::FromIterator;
 
 use crossbeam_queue::SegQueue;
@@ -58,6 +59,10 @@ impl<T> Queue<T> {
     pub fn len(&self) -> usize {
         self.queue.len()
     }
+    /// Returns `true` if the queue is empty.
+    pub fn is_empty(&self) -> bool {
+        self.queue.is_empty()
+    }
     /// Get available count. This is the difference between the current
     /// queue length and the number of tasks waiting for an item of the
     /// queue.
@@ -66,6 +71,16 @@ impl<T> Queue<T> {
     }
 }
 
+impl<T> Debug for Queue<T> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Queue")
+            .field("queue", &self.queue)
+            .field("semaphore", &self.semaphore)
+            .field("available", &self.available)
+            .finish()
+    }
+}
+
 impl<T> Default for Queue<T> {
     fn default() -> Self {
         Self {
